==> easyviper.core.api-1.0.1-sources.jar: com/ebmwebsourcing/easyviper/core/api/engine/expression/AssignementExpression.java <==
/**
* easy VIPER software - Copyright (c) 2009 PetalsLink, 
* http://www.petalslink.com/ 
*  
* This library is free software; you can redistribute it and/or modify it under 
* the terms of the GNU Lesser General Public License as published by the Free 
* Software Foundation; either version 2.1 of the License, or (at your option) 
* any later version. This library is distributed in the hope that it will be 
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
* General Public License for more details. 
*  
* You should have received a copy of the GNU Lesser General Public License 
* along with this library; if not, write to the Free Software Foundation, Inc., 
* 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.core.api.engine.expression;

import java.util.logging.Logger;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.engine.Scope;

/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
public interface AssignementExpression {

	public interface Assigner {

		void setLog(Logger logger);

		Expression affect(Scope scope, Expression left,
				Expression right) throws CoreException;

	}

	Expression getLeft();

	void setLeft(Expression left);

	Expression getRight();

	void setRight(Expression right);

	Assigner getAssigner();

	void setAssigner(Assigner assigner);

	void setLog(Logger logger);

}

==> easyviper.core.api-1.1-sources.jar: com/ebmwebsourcing/easyviper/core/api/engine/expression/AssignementExpression.java <==
/**
* easy VIPER software - Copyright (c) 2009 PetalsLink, 
* http://www.petalslink.com/ 
*  
* This library is free software; you can redistribute it and/or modify it under 
* the terms of the GNU Lesser General Public License as published by the Free 
* Software Foundation; either version 2.1 of the License, or (at your option) 
* any later version. This library is distributed in the hope that it will be 
* useful, but WITHOUT ANY WARRANTY; without even the implied warranty of 
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
* General Public License for more details. 
*  
* You should have received a copy of the GNU Lesser General Public License 
* along with this library; if not, write to the Free Software Foundation, Inc., 
* 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA 
 *  
 * ------------------------------------------------------------------------- 
 * $Id$ 
 * ------------------------------------------------------------------------- 
 */ 
package com.ebmwebsourcing.easyviper.core.api.engine.expression;

import java.util.logging.Logger;

import com.ebmwebsourcing.easyviper.core.api.CoreException;
import com.ebmwebsourcing.easyviper.core.api.engine.Scope;

/**
 * @author Nicolas Salatge - eBM WebSourcing
 */
public interface AssignementExpression {

	interface Assigner {

		void setLog(Logger logger);

		Expression affect(Scope scope, Expression left,
				Expression right) throws CoreException;

	}

	Expression getLeft();

	void setLeft(Expression left);

	Expression getRight();

	void setRight(Expression right);

	Assigner getAssigner();

	void setAssigner(Assigner assigner);

	void setLog(Logger logger);

}
